@@ -288,20 +288,6 @@ class TrackMeHandlerLicensingRead_v2(trackme_rest_handler.RESTHandler):
                             ):
                                 wlk_trackers.append(report)
 
-        # Count the number of active cim trackers
-        cim_trackers = []
-        splk_components = ["tenant_cim_objects"]
-
-        for kvrecord in collection.data.query(query=json.dumps(query_string)):
-            for splk_component in splk_components:
-                cim_tracker = kvrecord.get(splk_component)
-                if cim_tracker:
-                    cim_tracker = json.loads(cim_tracker)
-                    cim_reports = cim_tracker.get("reports")
-                    if cim_reports:
-                        for report in cim_reports:
-                            cim_trackers.append(report)
-
         #
         # check license
         #
@@ -433,12 +419,6 @@ class TrackMeHandlerLicensingRead_v2(trackme_rest_handler.RESTHandler):
                     # add to response
                     response["license_active_wlk_trackers_list"] = wlk_trackers
 
-                    # cim
-                    # add to response
-                    response["license_active_cim_trackers"] = len(cim_trackers)
-                    # add to response
-                    response["license_active_cim_trackers_list"] = cim_trackers
-
                     # add TrackMe version & schema_version_required
                     response["trackme_version"] = trackme_version
                     response["schema_version_required"] = schema_version_required
@@ -508,12 +488,6 @@ class TrackMeHandlerLicensingRead_v2(trackme_rest_handler.RESTHandler):
                     # add to response
                     response["license_active_wlk_trackers_list"] = wlk_trackers
 
-                    # cim
-                    # add to response
-                    response["license_active_cim_trackers"] = len(cim_trackers)
-                    # add to response
-                    response["license_active_cim_trackers_list"] = cim_trackers
-
                     # add TrackMe version & schema_version_required
                     response["trackme_version"] = trackme_version
                     response["schema_version_required"] = schema_version_required
@@ -582,12 +556,6 @@ class TrackMeHandlerLicensingRead_v2(trackme_rest_handler.RESTHandler):
                     # add to response
                     response["license_active_wlk_trackers_list"] = wlk_trackers
 
-                    # cim
-                    # add to response
-                    response["license_active_cim_trackers"] = len(cim_trackers)
-                    # add to response
-                    response["license_active_cim_trackers_list"] = cim_trackers
-
                     # add TrackMe version & schema_version_required
                     response["trackme_version"] = trackme_version
                     response["schema_version_required"] = schema_version_required
